@@ -5,22 +5,23 @@ use chrome_devtools as protocol;
 use futures_util::future::TryFutureExt;
 use futures_util::sink::SinkExt;
 use futures_util::stream::{SplitStream, StreamExt};
+use tokio_stream::wrappers::UnboundedReceiverStream;
 
 use crate::terminal::message::{Message, StdErr, StdOut};
 use tokio::net::TcpStream;
 use tokio::sync::mpsc;
-use tokio::time::delay_for;
-use tokio_native_tls::TlsStream;
-use tokio_tungstenite::stream::Stream;
-use tokio_tungstenite::{connect_async, tungstenite, WebSocketStream};
+use tokio::time::sleep;
 
+use tokio_tungstenite::{connect_async, tungstenite, MaybeTlsStream, WebSocketStream};
+
+use anyhow::{anyhow, Result};
 use url::Url;
 
 const KEEP_ALIVE_INTERVAL: u64 = 10;
 
 /// connect to a Workers runtime WebSocket emitting the Chrome Devtools Protocol
 /// parse all console messages, and print them to stdout
-pub async fn listen(socket_url: Url) -> Result<(), failure::Error> {
+pub async fn listen(socket_url: Url) -> Result<()> {
     // we loop here so we can issue a reconnect when something
     // goes wrong with the websocket connection
     loop {
@@ -46,7 +47,10 @@ pub async fn listen(socket_url: Url) -> Result<(), failure::Error> {
 
         // when the keep alive channel receives a message from the
         // heartbeat future, write it to the websocket
-        let keep_alive_to_ws = keep_alive_rx.map(Ok).forward(write).map_err(Into::into);
+        let keep_alive_to_ws = UnboundedReceiverStream::new(keep_alive_rx)
+            .map(Ok)
+            .forward(write)
+            .map_err(Into::into);
 
         // parse all incoming messages and print them to stdout
         let printer = print_ws_messages(read);
@@ -61,9 +65,7 @@ pub async fn listen(socket_url: Url) -> Result<(), failure::Error> {
 
 // Endlessly retry connecting to the chrome devtools instance with exponential backoff.
 // The backoff maxes out at 60 seconds.
-async fn connect_retry(
-    socket_url: &Url,
-) -> WebSocketStream<Stream<TcpStream, TlsStream<TcpStream>>> {
+async fn connect_retry(socket_url: &Url) -> WebSocketStream<MaybeTlsStream<TcpStream>> {
     let mut wait_seconds = 2;
     let maximum_wait_seconds = 60;
     let mut failed = false;
@@ -83,7 +85,7 @@ async fn connect_retry(
                     "Will retry connection in {} seconds",
                     wait_seconds
                 ));
-                delay_for(Duration::from_secs(wait_seconds)).await;
+                sleep(Duration::from_secs(wait_seconds)).await;
                 wait_seconds = wait_seconds.pow(2);
                 if wait_seconds > maximum_wait_seconds {
                     // max out at 60 seconds
@@ -96,18 +98,16 @@ async fn connect_retry(
 }
 
 async fn print_ws_messages(
-    mut read: SplitStream<WebSocketStream<Stream<TcpStream, TlsStream<TcpStream>>>>,
-) -> Result<(), failure::Error> {
+    mut read: SplitStream<WebSocketStream<MaybeTlsStream<TcpStream>>>,
+) -> Result<()> {
     while let Some(message) = read.next().await {
         match message {
             Ok(message) => {
                 let message_text = message.into_text().unwrap();
-                log::info!("{}", message_text);
+                log::info!("{}", &message_text);
 
-                let parsed_message: Result<protocol::Runtime, failure::Error> =
-                    serde_json::from_str(&message_text).map_err(|e| {
-                        failure::format_err!("this event could not be parsed:\n{}", e)
-                    });
+                let parsed_message: Result<protocol::Runtime> = serde_json::from_str(&message_text)
+                    .map_err(|e| anyhow!("this event could not be parsed:\n{}", e));
 
                 if let Ok(protocol::Runtime::Event(event)) = parsed_message {
                     // Try to parse json to pretty print, otherwise just print string
@@ -130,11 +130,9 @@ async fn print_ws_messages(
     Ok(())
 }
 
-async fn keep_alive(
-    tx: mpsc::UnboundedSender<tungstenite::protocol::Message>,
-) -> Result<(), failure::Error> {
+async fn keep_alive(tx: mpsc::UnboundedSender<tungstenite::protocol::Message>) -> Result<()> {
     let duration = Duration::from_millis(1000 * KEEP_ALIVE_INTERVAL);
-    let mut delay = delay_for(duration);
+    let mut delay = sleep(duration);
 
     // this is set to 2 because we have already sent an id of 1 to enable the runtime
     // eventually this logic should be moved to the chrome-devtools-rs library
@@ -148,6 +146,6 @@ async fn keep_alive(
         let keep_alive_message = tungstenite::protocol::Message::Text(keep_alive_message);
         tx.send(keep_alive_message).unwrap();
         id += 1;
-        delay = delay_for(duration);
+        delay = sleep(duration);
     }
 }
