@@ -1,9 +1,11 @@
 use std::env;
 use std::path::{Path, PathBuf};
 
+use anyhow::Result;
+
 pub const DEFAULT_CONFIG_FILE_NAME: &str = "default.toml";
 
-pub fn get_wrangler_home_dir() -> Result<PathBuf, failure::Error> {
+pub fn get_wrangler_home_dir() -> Result<PathBuf> {
     let config_dir = if let Ok(value) = env::var("WRANGLER_HOME") {
         log::info!("Using $WRANGLER_HOME: {}", value);
         Path::new(&value).to_path_buf()
@@ -16,7 +18,7 @@ pub fn get_wrangler_home_dir() -> Result<PathBuf, failure::Error> {
     Ok(config_dir)
 }
 
-pub fn get_global_config_path() -> Result<PathBuf, failure::Error> {
+pub fn get_global_config_path() -> Result<PathBuf> {
     let home_dir = get_wrangler_home_dir()?;
     let global_config_file = home_dir.join("config").join(DEFAULT_CONFIG_FILE_NAME);
     log::info!("Using global config file: {}", global_config_file.display());
